@@ -198,3 +198,21 @@ def test_warn_on_register_disabled(uses_sample_plugin, plugin_manager: PluginMan
     plugin_manager._manifests.pop(SAMPLE_PLUGIN_NAME)  # NOT good way to "unregister"
     with pytest.warns(UserWarning):
         plugin_manager.register(mf)
+
+
+def test_plugin_manager_dict(uses_sample_plugin, plugin_manager: PluginManager):
+    """Test exporting the plugin manager state with `dict()`."""
+    d = plugin_manager.dict()
+    assert SAMPLE_PLUGIN_NAME in d["plugins"]
+    assert "disabled" in d
+    assert "activated" in d
+
+    d = plugin_manager.dict(
+        include={"contributions", "package_metadata.version"},
+        exclude={"contributions.writers", "contributions.readers"},
+    )
+    plugin_dict = d["plugins"][SAMPLE_PLUGIN_NAME]
+    assert set(plugin_dict) == {"contributions", "package_metadata"}
+    contribs = set(plugin_dict["contributions"])
+    assert "readers" not in contribs
+    assert "writers" not in contribs
